==> rong-ui-react-0.0.7.tgz: package/es/picker/picker-column.js <==
var _setDefaultProps;

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

function _iterableToArrayLimit(arr, i) { var _i = arr == null ? null : typeof Symbol !== "undefined" && arr[Symbol.iterator] || arr["@@iterator"]; if (_i == null) return; var _arr = []; var _n = true; var _d = false; var _s, _e; try { for (_i = _i.call(arr); !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

import React from "react";
import { useState, memo, forwardRef, useEffect, useMemo, useImperativeHandle } from 'react';
import { createNamespace, classNames, setDefaultProps } from '../_util';
import PropTypes from 'prop-types';

var _createNamespace = createNamespace('picker-column'),
    bem = _createNamespace.bem;

var range = function range(num, min, max) {
  return Math.min(Math.max(num, min), max);
};

var PickerColumn = /*#__PURE__*/forwardRef(function (props, ref) {
  var column = props.column,
      isCascadingMenu = props.isCascadingMenu,
      itemHeight = props.itemHeight,
      baseOffset = props.baseOffset,
      columnValue = props.columnValue,
      columnIndex = props.columnIndex,
      onChange = props.onChange,
      timeStamp = props.timeStamp;

  var _useState = useState(0),
      _useState2 = _slicedToArray(_useState, 2),
      offset = _useState2[0],
      setOffset = _useState2[1]; // translate偏移量


  var _useState3 = useState(0),
      _useState4 = _slicedToArray(_useState3, 2),
      startY = _useState4[0],
      setStartY = _useState4[1]; // 鼠标起始位置


  var _useState5 = useState(0),
      _useState6 = _slicedToArray(_useState5, 2),
      startOffset = _useState6[0],
      setStartOffset = _useState6[1];

  var _useState7 = useState(0),
      _useState8 = _slicedToArray(_useState7, 2),
      touchstartTime = _useState8[0],
      setTouchstartTime = _useState8[1];

  var _useState9 = useState(0),
      _useState10 = _slicedToArray(_useState9, 2),
      duration = _useState10[0],
      setDuration = _useState10[1];

  var _useState11 = useState(0),
      _useState12 = _slicedToArray(_useState11, 2),
      selectedIndex = _useState12[0],
      setSelectedIndex = _useState12[1];

  var defaultDuration = 200; // 默认transition时间
  // 1,columnValue存在时计算默认selectedIndex。2，级联菜单联动时selectedIndex = 0

  useEffect(function () {
    var selectedIndex = 0;
    column.forEach(function (item, index) {
      if (item.value == columnValue || item.text === columnValue || item.title === columnValue) {
        selectedIndex = index;
      }
    });
    setSelectedIndex(selectedIndex);
    emitChange();
  }, [column, columnValue, timeStamp]); // selectedIndex change

  useEffect(function () {
    emitChange();
    resetOffset(selectedIndex);
  }, [selectedIndex]);

  var emitChange = function emitChange() {
    var obj = column[selectedIndex];
    if (obj) onChange(columnIndex, selectedIndex, column);
  };

  var handleListTouchStart = function handleListTouchStart(e) {
    setDuration(0);
    setStartY(e.targetTouches[0].clientY);
    setTouchstartTime(new Date());
  };

  var handleListTouchMove = function handleListTouchMove(e) {
    var deltaY = e.targetTouches[0].clientY - startY;
    var offset = range(startOffset + deltaY, -(column.length * itemHeight), itemHeight);
    setOffset(offset);
  };

  var handleListTouchEnd = function handleListTouchEnd(e) {
    /**
       * 惯性滑动思路
       * 在手指离开屏幕时，如果和上一次 move 时的间隔小于 `MOMENTUM_LIMIT_TIME` 且 move距离大于 `MOMENTUM_LIMIT_DISTANCE` 时，执行惯性滑动
       */
    var duration = new Date() - touchstartTime;
    var distance = offset - startOffset;
    var MOMENTUM_LIMIT_TIME = 300;
    var MOMENTUM_LIMIT_DISTANCE = 15;
    var allowMomentum = duration < MOMENTUM_LIMIT_TIME && Math.abs(distance) > MOMENTUM_LIMIT_DISTANCE;
    var selectedIndex = allowMomentum ? momentum(distance, duration) : getIndexByOffset(offset);
    setDuration(defaultDuration);
    setSelectedIndex(selectedIndex);
    resetOffset(selectedIndex);
  };

  var resetOffset = function resetOffset(selectedIndex) {
    var _offset = -selectedIndex * itemHeight;

    setOffset(_offset);
    setStartOffset(_offset);
  };

  var momentum = function momentum(distance, duration) {
    var speed = Math.abs(distance / duration);
    distance = offset + speed / 0.003 * (distance < 0 ? -1 : 1);
    var selectedIndex = getIndexByOffset(distance);
    return selectedIndex;
  };

  var getIndexByOffset = function getIndexByOffset(offset) {
    return range(Math.round(-offset / itemHeight), 0, column.length - 1);
  };

  var toSetSelectedIndex = function toSetSelectedIndex(selectedIndex) {
    var offset = -selectedIndex * itemHeight;
    setOffset(offset);
    setStartOffset(offset);
    setSelectedIndex(selectedIndex);
    setDuration(defaultDuration);
  };

  var ulStyle = {
    transform: "translate3d(0, ".concat(offset + baseOffset, "px, 0)"),
    transitionDuration: "".concat(duration, "ms"),
    transitionProperty: duration ? 'all' : 'none'
  };
  console.log('pickerColumn mounted or update');
  return /*#__PURE__*/React.createElement("ul", {
    className: bem({
      'flex-1': !isCascadingMenu
    }),
    style: ulStyle,
    onTouchStart: handleListTouchStart,
    onTouchMove: handleListTouchMove,
    onTouchEnd: handleListTouchEnd
  }, column.map(function (item, index) {
    var text = item.text || item.title;
    return /*#__PURE__*/React.createElement("li", {
      key: text
    }, text);
  }));
});
setDefaultProps(PickerColumn, (_setDefaultProps = {
  column: {
    type: PropTypes.array
  },
  columnIndex: {
    type: PropTypes.number
  },
  columnValue: {
    type: PropTypes.oneOfType([PropTypes.number, PropTypes.string])
  },
  itemHeight: {
    type: PropTypes.number
  },
  baseOffset: {
    type: PropTypes.number
  },
  isCascadingMenu: {
    type: PropTypes.bool
  }
}, _defineProperty(_setDefaultProps, "itemHeight", {
  type: PropTypes.number
}), _defineProperty(_setDefaultProps, "onChange", {
  type: PropTypes.func,
  default: function _default(selectedVal, selectedIndex, columnIndex) {}
}), _setDefaultProps));
export default /*#__PURE__*/memo(PickerColumn);

==> rong-ui-react-0.0.8.tgz: package/es/picker/picker-column.js <==
function _typeof(o) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (o) { return typeof o; } : function (o) { return o && "function" == typeof Symbol && o.constructor === Symbol && o !== Symbol.prototype ? "symbol" : typeof o; }, _typeof(o); }
function _defineProperty(obj, key, value) { key = _toPropertyKey(key); if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }
function _toPropertyKey(arg) { var key = _toPrimitive(arg, "string"); return _typeof(key) === "symbol" ? key : String(key); }
function _toPrimitive(input, hint) { if (_typeof(input) !== "object" || input === null) return input; var prim = input[Symbol.toPrimitive]; if (prim !== undefined) { var res = prim.call(input, hint || "default"); if (_typeof(res) !== "object") return res; throw new TypeError("@@toPrimitive must return a primitive value."); } return (hint === "string" ? String : Number)(input); }
function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }
function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }
function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }
function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i]; return arr2; }
function _iterableToArrayLimit(r, l) { var t = null == r ? null : "undefined" != typeof Symbol && r[Symbol.iterator] || r["@@iterator"]; if (null != t) { var e, n, i, u, a = [], f = !0, o = !1; try { if (i = (t = t.call(r)).next, 0 === l) { if (Object(t) !== t) return; f = !1; } else for (; !(f = (e = i.call(t)).done) && (a.push(e.value), a.length !== l); f = !0); } catch (r) { o = !0, n = r; } finally { try { if (!f && null != t.return && (u = t.return(), Object(u) !== u)) return; } finally { if (o) throw n; } } return a; } }
function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }
import React from "react";
import { useState, memo, forwardRef, useEffect, useMemo, useImperativeHandle } from 'react';
import { createNamespace, classNames, setDefaultProps } from '../_util';
import PropTypes from 'prop-types';
var _createNamespace = createNamespace('picker-column'),
  bem = _createNamespace.bem;
var range = function range(num, min, max) {
  return Math.min(Math.max(num, min), max);
};
var PickerColumn = /*#__PURE__*/forwardRef(function (props, ref) {
  var column = props.column,
    isCascadingMenu = props.isCascadingMenu,
    itemHeight = props.itemHeight,
    baseOffset = props.baseOffset,
    columnValue = props.columnValue,
    columnIndex = props.columnIndex,
    onChange = props.onChange,
    timeStamp = props.timeStamp;
  var _useState = useState(0),
    _useState2 = _slicedToArray(_useState, 2),
    offset = _useState2[0],
    setOffset = _useState2[1]; // translate偏移量
  var _useState3 = useState(0),
    _useState4 = _slicedToArray(_useState3, 2),
    startY = _useState4[0],
    setStartY = _useState4[1]; // 鼠标起始位置
  var _useState5 = useState(0),
    _useState6 = _slicedToArray(_useState5, 2),
    startOffset = _useState6[0],
    setStartOffset = _useState6[1];
  var _useState7 = useState(0),
    _useState8 = _slicedToArray(_useState7, 2),
    touchstartTime = _useState8[0],
    setTouchstartTime = _useState8[1];
  var _useState9 = useState(0),
    _useState10 = _slicedToArray(_useState9, 2),
    duration = _useState10[0],
    setDuration = _useState10[1];
  var _useState11 = useState(0),
    _useState12 = _slicedToArray(_useState11, 2),
    selectedIndex = _useState12[0],
    setSelectedIndex = _useState12[1];
  var defaultDuration = 200; // 默认transition时间

  // 1,columnValue存在时计算默认selectedIndex。2，级联菜单联动时selectedIndex = 0
  useEffect(function () {
    var selectedIndex = 0;
    column.forEach(function (item, index) {
      if (item.value == columnValue || item.text === columnValue || item.title === columnValue) {
        selectedIndex = index;
      }
    });
    setSelectedIndex(selectedIndex);
    emitChange();
  }, [column, columnValue, timeStamp]);

  // selectedIndex change
  useEffect(function () {
    emitChange();
    resetOffset(selectedIndex);
  }, [selectedIndex]);
  var emitChange = function emitChange() {
    var obj = column[selectedIndex];
    if (obj) onChange(columnIndex, selectedIndex, column);
  };
  var handleListTouchStart = function handleListTouchStart(e) {
    setDuration(0);
    setStartY(e.targetTouches[0].clientY);
    setTouchstartTime(new Date());
  };
  var handleListTouchMove = function handleListTouchMove(e) {
    var deltaY = e.targetTouches[0].clientY - startY;
    var offset = range(startOffset + deltaY, -(column.length * itemHeight), itemHeight);
    setOffset(offset);
  };
  var handleListTouchEnd = function handleListTouchEnd(e) {
    /**
       * 惯性滑动思路
       * 在手指离开屏幕时，如果和上一次 move 时的间隔小于 `MOMENTUM_LIMIT_TIME` 且 move距离大于 `MOMENTUM_LIMIT_DISTANCE` 时，执行惯性滑动
       */
    var duration = new Date() - touchstartTime;
    var distance = offset - startOffset;
    var MOMENTUM_LIMIT_TIME = 300;
    var MOMENTUM_LIMIT_DISTANCE = 15;
    var allowMomentum = duration < MOMENTUM_LIMIT_TIME && Math.abs(distance) > MOMENTUM_LIMIT_DISTANCE;
    var selectedIndex = allowMomentum ? momentum(distance, duration) : getIndexByOffset(offset);
    setDuration(defaultDuration);
    setSelectedIndex(selectedIndex);
    resetOffset(selectedIndex);
  };
  var resetOffset = function resetOffset(selectedIndex) {
    var _offset = -selectedIndex * itemHeight;
    setOffset(_offset);
    setStartOffset(_offset);
  };
  var momentum = function momentum(distance, duration) {
    var speed = Math.abs(distance / duration);
    distance = offset + speed / 0.003 * (distance < 0 ? -1 : 1);
    var selectedIndex = getIndexByOffset(distance);
    return selectedIndex;
  };
  var getIndexByOffset = function getIndexByOffset(offset) {
    return range(Math.round(-offset / itemHeight), 0, column.length - 1);
  };
  var toSetSelectedIndex = function toSetSelectedIndex(selectedIndex) {
    var offset = -selectedIndex * itemHeight;
    setOffset(offset);
    setStartOffset(offset);
    setSelectedIndex(selectedIndex);
    setDuration(defaultDuration);
  };
  var ulStyle = {
    transform: "translate3d(0, ".concat(offset + baseOffset, "px, 0)"),
    transitionDuration: "".concat(duration, "ms"),
    transitionProperty: duration ? 'all' : 'none'
  };
  console.log('pickerColumn mounted or update');
  return /*#__PURE__*/React.createElement("ul", {
    className: bem({
      'flex-1': !isCascadingMenu
    }),
    style: ulStyle,
    onTouchStart: handleListTouchStart,
    onTouchMove: handleListTouchMove,
    onTouchEnd: handleListTouchEnd
  }, column.map(function (item, index) {
    var text = item.text || item.title;
    return /*#__PURE__*/React.createElement("li", {
      key: text
    }, text);
  }));
});
setDefaultProps(PickerColumn, _defineProperty(_defineProperty({
  column: {
    type: PropTypes.array
  },
  columnIndex: {
    type: PropTypes.number
  },
  columnValue: {
    type: PropTypes.oneOfType([PropTypes.number, PropTypes.string])
  },
  itemHeight: {
    type: PropTypes.number
  },
  baseOffset: {
    type: PropTypes.number
  },
  isCascadingMenu: {
    type: PropTypes.bool
  }
}, "itemHeight", {
  type: PropTypes.number
}), "onChange", {
  type: PropTypes.func,
  default: function _default(selectedVal, selectedIndex, columnIndex) {}
}));
export default /*#__PURE__*/memo(PickerColumn);
